
# Slot: primary_email


The main email address of a person

URI: [nwb_schema_language:primary_email](https://w3id.org/p2p_ld/nwb-schema-language/primary_email)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children

 *  [Namespaces➞primary_email](Namespaces_primary_email.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | schema:email |

